@@ -31,7 +31,7 @@ setMethodS3("getFileClass", "FirmaSet", function(static, ...) {
   FirmaFile
 }, static=TRUE, private=TRUE)
 
-setMethodS3("byPath", "FirmaSet", function(static, ..., pattern=",FIRMAscores[.](c|C)(e|E)(l|L)$", fileClass=NULL) {
+setMethodS3("byPath", "FirmaSet", function(static, ..., pattern=",FIRMAscores[.](c|C)(e|E)(l|L)(|[.]lnk|[.]LNK)$", fileClass=NULL) {
   # Argument 'fileClass':
   if (is.null(fileClass))
     fileClass <- gsub("Set$", "File", class(static)[1])
