@@ -21,13 +21,5 @@
 # @author "KS"
 #*/###########################################################################
 setConstructorS3("QualityAssessmentSet", function(...) {
-  extend(AffymetrixCelSet(...), "QualityAssessmentSet");
+  extend(AffymetrixCelSet(...), "QualityAssessmentSet")
 })
-
-##########################################################################
-# HISTORY:
-# 2007-12-10
-# o Now a QualityAssessmentSet is a plain AffymetrixCelSet.
-# o Removed argument 'tags' to constructor of QualityAssessmentSet,
-#   because it was never used anywhere.
-##########################################################################
